#
# spec file for package IfcOpenShell
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{suse_version} < 1330
%bcond_with opencollada
%endif

%bcond_with need_clang

Name:           IfcOpenShell
Version:        0.4.99+git20170216.1454
Release:        2.10
Summary:        Library for working with the Industry Foundation Classes (IFC) file format
License:        GPL-3.0+
Group:          Productivity/Graphics/CAD
Url:            http://ifcopenshell.org/
Source0:        ifcopenshell.tar.xz
Source1:        shared.diff
BuildRequires:  OpenCASCADE-devel
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libpcre)
%if %{with opencollada}
BuildRequires:  openCOLLADA-devel
%endif
BuildRequires:  swig
BuildRequires:  python-devel
%if %{with need_clang}
BuildRequires:  llvm-clang
BuildRequires:  llvm
%else
BuildRequires:  gcc
BuildRequires:  gcc-c++
%endif
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
IfcOpenShell is an open source (LGPL) software library for working with the Industry Foundation Classes (IFC) file format. Currently supported IFC releases are IFC2x3 TC1 and IFC4.

For more information, see
http://ifcopenshell.org
http://academy.ifcopenshell.org

%package devel
Summary:        Development files for IfcOpenShell
Group:          Development/Libraries/C and C++

%description devel
Development files for IfcOpenShell.


%prep
%setup -q -n ifcopenshell
patch --merge -p1 < %{S:1}

%build
mkdir build
cd build
%if %{with need_clang}
    OPTFLAGS="$(echo %{optflags} | sed "s:-grecord-gcc-switches::g") -flto"
%else
    # -fno-var-tracking could speed up builds ...
    OPTFLAGS="%{optflags}"
%endif
  CFLAGS="$OPTFLAGS" \
  CXXFLAGS="$OPTFLAGS" \
  cmake ../cmake \
    -DBINDIR=%{_bindir} \
    -DINCLUDEDIR=%{_includedir} \
    -DLIBDIR=%{_libdir} \
    -DBUILD_SHARED_LIBS=ON \
    -DCMAKE_SKIP_BUILD_RPATH=ON \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
%if %{with need_clang}
    -DCMAKE_C_COMPILER=clang \
    -DCMAKE_CXX_COMPILER=clang++ \
    -DCMAKE_AR=%{_bindir}/llvm-ar \
    -DCMAKE_RANLIB=%{_bindir}/llvm-ranlib \
    -DCMAKE_NM=%{_bindir}/llvm-nm \
    -DCMAKE_OBJDUMP=%{_bindir}/llvm-objdump \
%endif
    -DOCC_LIBRARY_DIR=%{_libdir}/oce \
    -DUNICODE_SUPPORT=ON \
%if %{with opencollada}
    -DOPENCOLLADA_INCLUDE_DIR=%{_includedir} \
    -DCOLLADA_SUPPORT=ON \
%else
    -DCOLLADA_SUPPORT=OFF \
%endif
    -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DIFCCONVERT_DOUBLE_PRECISION=ON \
    -DUSE_IFC4=OFF \
    -DBUILD_IFCPYTHON=ON \
    -DBUILD_EXAMPLES=OFF \
    -DUSE_VLD=OFF \
    -DBUILD_IFCMAX=OFF
  make %{?_smp_mflags} -j1
cd ..

%install
cd build
  make DESTDIR=%{buildroot} install %{?_smp_mflags}
cd ..

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/Ifc*
%{_libdir}/libIfcGeom.so
%{python_sitearch}/ifcopenshell

%files devel
%defattr(-,root,root)
%{_includedir}/ifcgeom
%{_includedir}/ifcparse

%changelog
* Sun May 15 2016 johannesobermayr@gmx.de
- initial package
